# emachinery
A package for analysis of electric machinery.

## Functions

### 1. Machine Quantitie Calculations & Conversion

## PYPI
https://test.pypi.org/project/emachinery/1.0.0/













----
This package is published following https://www.youtube.com/watch?v=Qs91v2Tofys
